function [s,f,t] = audio_spectrogram( y, RATE, BINS, TIME_STEP, OVERLAP,...
                                      window_fcn );
% [s,f,t] = audio_spectrogram( y, RATE, BINS, TIME_STEP, OVERLAP, window_fcn );
%
% BINS is the number of frequency bins
% TIME_STEP is the size of each time bin (in seconds)
% OVERLAP is between 0 and 1 and indicates the amount of window overlap
% window_fcn can be @hamming (default), @rectwin, @hann, @blackman  
% returns s(frequency,time), and the corresponding frequencies and times (f,t)
%

if( nargin < 5 )
    OVERLAP = 0;
end
if( nargin < 6 )
    window_fcn = @hamming;
end

% NOTE: matlab sigproc toolbox's built-in SPECTROGRAM is a better choice
% as follows
NFFT=(BINS-1)*2;
WINDOWS=1; % number of windows to break recording into for spectra
window_length = round(RATE*TIME_STEP/WINDOWS);
[s,f,t,p] = spectrogram( y, window_fcn(window_length), ...
                         OVERLAP*window_length, NFFT, RATE );
s = smooth_downsample_by_row( p, WINDOWS );

