function [fingerprints,group] = calc_fp_from_files( room_patterns, fp_type,...
                                                    TAKE_SIZE, varargin );
% returns a matrix of column-vector fingerprints
% optional parameters include all those for calc_spec.m
% set TAKE_SIZE to 1 if you just want to laod the fingerprints, otherwise
% if TAKE_SIZE==4 then it verifies that 8 samples are available for each room

% Set default parameter values.  These are the optimal settings according to
% the Mobisys11 results.
RATE=96000;
recording_len=0;

% parse function arguments
if( mod( length(varargin), 2 ) ~= 0 )
    error( 'ERROR: an odd number of parameters was expected' );
end
for i=1:2:length(varargin)
    switch( varargin{i} )
        case 'sample_rate'
          RATE = varargin{i+1};
        case 'recording_len'
          recording_len = varargin{i+1};
    end
end

if( recording_len == 0 )
    error( 'You must set recording_len parameter' )
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RECORDING PROCESSING
% read the wav files to get spectra

% each sample is labelled with a class/group number:
clear group;
take=0;
k=0; % iterator into the recordings

num_rooms = size( room_patterns, 1 );
for i=1:num_rooms,
    wav_files = {};
    room_i_samples=0;
    for l=1:length(room_patterns(i,:)), % each room can have multiple patterns
        % add to list of files
        file_structs = dir( char(room_patterns(i,l)) );
        dirname = fileparts( room_patterns{i,l} );
        for j=1:length(file_structs),
            % don't allow the number of samples for each room to exceed 8 
            % (2 visits * 4 samples/visit).  This prevents classifier bias.
            room_i_samples = room_i_samples + 1;
            if( room_i_samples > 8 ),
                break;
            end

            wav_files = [wav_files; [dirname, '/', file_structs(j).name] ];

            % store group label for this sample
            k=k+1;
            group(k,1)=i;
        end
    end
    if( room_i_samples < 8 && TAKE_SIZE == 4 ),
        error( sprintf( 'Room %s has only %d samples', ...
                        char(room_patterns(i,l)), room_i_samples ) );
    end 
    num_rec = length( wav_files );

    for j=1:num_rec,
        take=take+1;

	%fprintf('computing spectrum %d',take);
        fprintf( '%s\n', wav_files{j} );

        % read wav file
        y = wavread( wav_files{j}, [0*RATE+1 recording_len*RATE] );
	y = squeeze(y(:,1)); % discard right channel

        switch( fp_type )
          case 'ABS'
            fingerprints(:,take) = calc_spec( y, varargin{:} );
          case 'surroundsense'
            fingerprints(:,take) = calc_hist( y, varargin{:} );
        end
    end
end



