% run mobisys_study.m first

RATE = 96000;

% occupancy pairs: [time in minutes, occupancy]
occupancy_pairs_silent = [
0 1;
1000 1;
];

occupancy_pairs_econ = [
0 2;
4 3;
7 2;
11.5 3;
13 8;
14 12;
15 16;
17 25;
18 27;
19 29;
20 33;
21 37;
22 38;
23 40;
24 42;
27 43;
31 44;
65 43;
94.5 43;
95.5 20;
97 4;
1000 4
];

occupancy_pairs_game = [
0 9;
2 10;
3 12;
3.5 16;
6 20;
7 23;
8 24;
9 26;
10 28;
11 29;
43 29;
44 23;
56.5 23;
62 18;
1000 18;
];

% 
noise_types = {'silent','chatter','conversation'};
noise_pairs_silent = [
0 1;
1000 1
];

noise_pairs_econ = [
0 1;
12.99 1;
13 2;
20.29 2;
20.3 3;
94.49 3;
94.5 2;
1000 2
];

noise_pairs_game = [
0 2;
10.99 2;
11 3;
36.99 3;
37 2;
55.49 2;
55.5 3;
56.49 3;
56.5 2;
1000 2;
];

% 
noise_pairs_ford_silent = [
0 1;
1000 1;
];

occupancy_pairs_ford_silent = [
0 1;
1000 1;
];

occupancy_pairs_donuts = [
0 4;
0.25 5;
5.75 4;
12 7;
12.5 4
19.75 1
23.5 0
24.5 1
29.5 0
31.5 1
36.5 0
37.49 0
37.5 5
41.25 4
44 3
46.5 2
46.74 2
46.75 1
47.5 0
47.99 0
48 2
48.25 1
49 0
50.25 1
1000 1
];

% define state to be lecture (3) if occupancy > 1, else state is silent (1)
noise_pairs_donuts = [ occupancy_pairs_donuts(:,1) ...
                       1+2*(occupancy_pairs_donuts(:,2)>1)];


MAX_OCCUPANCY = 50;
SEGMENT_LEN=30; % seconds
SPEC_RES = 2^11;
% switch the SUMMARY_TYPE for comparison
SUMMARY_TYPE='p05';
%SUMMARY_TYPE='mean';
PROCESSING='post-norm-log';
%PROCESSING='post-curve';
TIME_STEP=0.1;


%% set this variable to 1 to use the 'donuts' data set from Ford 3.317
%% rather than the 'lecture' data set from Tech LR5
for USE_DONUTS=0:1
    if( USE_DONUTS )
        wavfiles = { '../passive/ford_3317_*.wav', '../donuts_h4n.wav' };
        occupancy_pairs = { occupancy_pairs_ford_silent, ...
                            occupancy_pairs_donuts };
        noise_pairs = { noise_pairs_ford_silent, noise_pairs_donuts };
        ROOM = 4; % index in the variable 'room_patterns' in mobisys_study.m
    else
        wavfiles = { '../passive/tech_lr5_*.wav', ...
                     '../lectures/110412-*.wav', ...
                     '../lectures/110413-*.wav' };
        occupancy_pairs = { occupancy_pairs_silent, occupancy_pairs_econ, ...
                            occupancy_pairs_game }; 
        noise_pairs = { noise_pairs_silent, noise_pairs_econ, ...
                        noise_pairs_game };
        ROOM = 22;
    end
    
    occ = [];
    noise = [];
    fp = [];
    for i=1:length(wavfiles)
        % load recordings
        file_structs = dir( wavfiles{i} );
        dirname = fileparts( wavfiles{i} );
        y = [];
        for j=1:length(file_structs),
            y1 = wavread( [dirname, '/', file_structs(j).name] );
            y1 = squeeze(y1(:,1)); % discard right channel
                                   % Thrown out samples beyond the last 
                                   % full SEGMENT so they don't get
                                   % mixed with those from the next wav file.
            samp = (SEGMENT_LEN*RATE) * floor( length(y1) / (SEGMENT_LEN*RATE) );
            y1 = y1(1:samp);
            y = [y;y1]; 
            clear y1;
        end
        
        segment_idx = 0;
        for idx = 1 : SEGMENT_LEN*RATE : length(y)-SEGMENT_LEN*RATE
            segment_idx = segment_idx+1;
            time = (idx-1)/RATE;
            %disp( sprintf('time: %d', time ) );
            
            % generate ABS fingerprint
            fp(end+1,:) = calc_spec( y(idx:idx+SEGMENT_LEN*RATE),'band',band{1} );
            
            % find occupancy level for this fingerprint
            occ(end+1) = interp1( occupancy_pairs{i}(:,1), ...
                                  occupancy_pairs{i}(:,2), ...
                                  time/60, 'nearest' );
            % find noise level for this fingerprint
            noise(end+1) = interp1( noise_pairs{i}(:,1), ...
                                    noise_pairs{i}(:,2), ...
                                    time/60, 'nearest' );
        end
    end

    % find mean value of fingerprints
    n = size(fp,2);
    % we will record an average spectrogram summary for each occupancy level.
    occupancy_spectra = zeros( MAX_OCCUPANCY,n ); 
    occupancy_count = zeros( MAX_OCCUPANCY,1 ); 
    for i=1:MAX_OCCUPANCY
        ind = find( occ==i );
        occupancy_spectra(i,:) = mean( fp(ind,:) );
        occupancy_count = length(ind);
    end
    % ... and for each noise level.
    noise_spectra = zeros( 3,n ); 
    noise_count = zeros( 3,1 );
    for i=1:3
        ind = find( noise==i );
        noise_spectra(i,:) = mean( fp(ind,:) );
        noise_count = length(ind);
    end

    if( 0 )
        % PLOT RESULTS
        figure
        subplot( 2,1, 1 )
        plot( [occ; noise]')
        axis( [0 length(occ) 0 max(occ)] );
        subplot( 2,1, 2 )   
        %colormap( 1-gray(256) );
        imagesc(fp') 
        set(gca,'YDir','normal');
    end

    % compare to fingerprints from rest of rooms
    score = [-1 -1 -1];
    for j=1:3
        if( sum(find(noise==j))>0 )
            class = nnclassify( fp(find(noise==j),:), spectra',...
                                group, 1, 'euclidean' );
            score(j) = sum(class==ROOM)/length(class);
        end
    end
    if( USE_DONUTS )
        disp(sprintf('\t3.317\t%.3f\t%.3f\t%.3f',score(1),score(3),score(2)));
    else
        disp(sprintf('\tLR5\t%.3f\t%.3f\t%.3f',score(1),score(3),score(2)));
    end
end