function y = matrix_summary( X, mode )
% y = matrix_summary( spectrogram, mode )
%
% returns a summary vector for the columns of X.
%
% mode may be one of:
% 'mean' - take the mean for each row
% 'median' - take the median for each row
% 'min' - take the minimum value for each row
% 'max' - take the maximum value for each row
% 'p95' - take the 95th percentile value for each row (almost max)
% 'p05' - take the 5th percentile value for each row (almost min)

% default value for mode parameter
if ~exist('mode')
   mode = 'mean'
end

switch( mode )
    case 'mean'
	y = mean(X')';
    case 'median'
	y = median(X')';
    case 'min'
	y = min(X')';
    case 'max'
	y = max(X')';
    case 'p95'
	sorted = sort(X');
	y = sorted( ceil( .95 * size(X,2) ), : )';
    case 'p05'
	sorted = sort(X');
	y = sorted( ceil( .05 * size(X,2) ), : )';
    case 'p10'
	sorted = sort(X');
	y = sorted( ceil( .10 * size(X,2) ), : )';
    case 'p25'
	sorted = sort(X');
	y = sorted( ceil( .25 * size(X,2) ), : )';
end
