function [score,confusion] = classify( all_samples, all_group, TAKE_SIZE, ...
                                       population_frac, metric )
% all_samples is a matrix of column-vector samples, 
% ie, it is all_samples(frequency,sample#)

% default parameter values
if( nargin < 4 )
    population_frac = 1;
end
if( nargin < 5 )
    metric='euclidean';
end
num_rooms = length(unique(all_group));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PARAMETERS
%metric={ 'euclidean','cityblock' };%,'correlation' };
%metric={ 'cityblock','cosine' };
classifier=@nnclassify; 
%classifier={ @nnclassify, @gaussian_classify }; 
%%nn=[1 3 5];
nn=1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% population fraction (chosen randomly)
N=length(all_group);
perm = randperm(num_rooms);
population_idx = [];
for i=1:N,
    if( sum(perm(1:round(num_rooms*population_frac))==all_group(i)) )
        population_idx = [population_idx i];
    end
end
clear samples;
samples = all_samples(:,population_idx);
clear group;
group = all_group( population_idx );


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CLASSIFICATION

% Divide samples into testing and training.
clear class;
    
class_func = classifier;

% test each 'take'
for j=1:TAKE_SIZE:length(group),
    % cutoff defines the outer (non-inclusive) boundary of the test data
    cutoff = [j-1; j+TAKE_SIZE];
    new_training = [ samples(:,1:cutoff(1)) samples(:,cutoff(2):end) ]';
    new_group = [ group(1:cutoff(1)); group( cutoff(2):end) ];
    new_test = samples( :, cutoff(1)+1:cutoff(2)-1 )';
    

    % Discard some of the training data to
    % make sure that there is not more training data for incorrect
    % samples than for correct sample (this would normally be the case
    % because we would use two visits training for incorrect samples but
    % only one visit training for correct samples).
    unique_group = unique(group);
    training_keepers = [];
    training_per_room = sum( new_group==group(j) );
    for gid_i=1:length(unique_group), % for each room in this sample
        training_i = find( new_group==unique_group(gid_i) );
        if( length(training_i) > training_per_room ),
            if( TAKE_SIZE == 4 )
                if( length(training_i) < 2* training_per_room ),
                    disp( 'ERROR unexpected training sample size' );
                end
                % choose every other sample from this room until we have enough
                training_i = training_i(1:2:2*training_per_room);
            else
                training_i = training_i;
            end
        end
        training_keepers = [training_keepers; training_i];
    end
    new_group = new_group(training_keepers);
    new_training = new_training(training_keepers,:);        
    
    
    % call the classifier
    if( isequal( class_func, @nnclassify ) ),
        % nnclassify function takes additional paramenters
        class(j:j+TAKE_SIZE-1) = class_func( new_test, new_training, ...
                                             new_group, nn, metric );
    else
        class(j:j+TAKE_SIZE-1) = class_func( new_test, new_training, ...
                                             new_group);
    end
end

% compute confusion matrix
confusion = zeros( num_rooms, num_rooms );
for i=1:num_rooms,
    this_room_results = class .* (group==i)'; % mask on room id
    for j=1:num_rooms,
        confusion(i,j) = sum(this_room_results==j);
    end
end

% compute pairwise feature vector distances
distance=squareform(pdist(samples', metric ));

% how often was the classifier correct?
score = sum( class==group' ) / length(group);    
